@@ -41,7 +41,7 @@ class parameter(object):
                  parameter_development=None, parameter_plots=None, parameter_path_threshold=None,
                  path_gaps_estimated =0, parameter_gap_estimations = [],
                  contamination_mean=None, contamination_stddev = None, contamination_ratio=0,
-                 no_score=None):
+                 no_score=None, orientation = None):
 
         # Library information
         # Contig information
@@ -79,6 +79,7 @@ class parameter(object):
         self.plots = parameter_plots
         self.path_threshold = parameter_path_threshold
         self.no_score = no_score
+        self.orientation = orientation
 
         # related to gap distances
         self.path_gaps_estimated = path_gaps_estimated
